pub struct BannerlordModuleInfo {
pub id: String,
pub name: String,
pub dependencies: Vec<String>,
}Expand description
Module identity and declared dependencies parsed from a SubModule.xml.
Fields
id: Stringname: Stringdependencies: Vec<String>Trait Implementations
Sourceimpl Clone for BannerlordModuleInfo
impl Clone for BannerlordModuleInfo
Sourcefn clone(&self) -> BannerlordModuleInfo
fn clone(&self) -> BannerlordModuleInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BannerlordModuleInfo
impl Debug for BannerlordModuleInfo
impl Eq for BannerlordModuleInfo
Sourceimpl PartialEq for BannerlordModuleInfo
impl PartialEq for BannerlordModuleInfo
Sourcefn eq(&self, other: &BannerlordModuleInfo) -> bool
fn eq(&self, other: &BannerlordModuleInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BannerlordModuleInfo