pub struct SelectionDiff {
pub step: String,
pub group: String,
pub left: Vec<String>,
pub right: Vec<String>,
}Expand description
A difference between two declarative configs for a specific group.
Fields
step: Stringgroup: Stringleft: Vec<String>right: Vec<String>Trait Implementations
Sourceimpl Clone for SelectionDiff
impl Clone for SelectionDiff
Sourcefn clone(&self) -> SelectionDiff
fn clone(&self) -> SelectionDiff
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SelectionDiff
impl Debug for SelectionDiff
Sourceimpl PartialEq for SelectionDiff
impl PartialEq for SelectionDiff
Sourcefn eq(&self, other: &SelectionDiff) -> bool
fn eq(&self, other: &SelectionDiff) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SelectionDiff
impl StructuralPartialEq for SelectionDiff