pub enum DeclarativeError {
UnsupportedVersion {
config: u32,
supported: u32,
},
HashMismatch {
expected: String,
actual: String,
},
StepNotFound(String),
GroupNotFound {
step: String,
group: String,
},
PluginNotFound {
step: String,
group: String,
plugin: String,
},
ValidationFailed {
step: String,
group: String,
message: String,
},
}Expand description
Error from applying a declarative config.
Variants
UnsupportedVersion
Config schema version is newer than this library supports.
HashMismatch
The installer XML hash doesn’t match. The installer has been updated.
StepNotFound(String)
Referenced step name not found in the FOMOD config.
GroupNotFound
Referenced group name not found within the given step.
PluginNotFound
Referenced plugin name not found within the given group.
ValidationFailed
Selection violates the group’s constraints.