pub fn read_native_plugin_order(game_id: &str) -> Result<Vec<PluginEntry>>Expand description
Read the native plugin order for a game from plugins.txt, when the game uses one.
pub fn read_native_plugin_order(game_id: &str) -> Result<Vec<PluginEntry>>Read the native plugin order for a game from plugins.txt, when the game uses one.