pub struct AddUserGameResult {
pub path: PathBuf,
pub existed: bool,
}Expand description
Outcome of add_user_game: where the spec was written and whether it existed already.
Fields
path: PathBufexisted: boolTrait Implementations
Sourceimpl Clone for AddUserGameResult
impl Clone for AddUserGameResult
Sourcefn clone(&self) -> AddUserGameResult
fn clone(&self) -> AddUserGameResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddUserGameResult
impl Debug for AddUserGameResult
Sourceimpl PartialEq for AddUserGameResult
impl PartialEq for AddUserGameResult
Sourcefn eq(&self, other: &AddUserGameResult) -> bool
fn eq(&self, other: &AddUserGameResult) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AddUserGameResult
impl StructuralPartialEq for AddUserGameResult