pub struct DetectCandidateDir {
pub relative_dir: String,
pub exe_names: Vec<String>,
pub total_size: u64,
}Expand description
A candidate game directory found by detect_candidates, with its
executables and total size to help rank likely game roots.
Fields
relative_dir: Stringexe_names: Vec<String>total_size: u64Trait Implementations
Sourceimpl Clone for DetectCandidateDir
impl Clone for DetectCandidateDir
Sourcefn clone(&self) -> DetectCandidateDir
fn clone(&self) -> DetectCandidateDir
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DetectCandidateDir
impl Debug for DetectCandidateDir
Sourceimpl Display for DetectCandidateDir
impl Display for DetectCandidateDir
Sourceimpl PartialEq for DetectCandidateDir
impl PartialEq for DetectCandidateDir
Sourcefn eq(&self, other: &DetectCandidateDir) -> bool
fn eq(&self, other: &DetectCandidateDir) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for DetectCandidateDir
impl StructuralPartialEq for DetectCandidateDir